@@ -1,17 +1,19 @@
 #!/usr/bin/perl
-# DocumentId:	$Id: debarchiver.pl 2151 2005-11-07 20:50:20Z ola $
+# DocumentId:	$Id: debarchiver.pl 2210 2006-07-05 21:52:53Z ola $
 # Author:	$Author: ola $
-# Date:		$Date: 2005-11-07 21:50:20 +0100 (mån, 07 nov 2005) $
+# Date:		$Date: 2006-07-05 23:52:53 +0200 (ons, 05 jul 2006) $
 # Version:	$Revision: 1.49 $
 # Summary:
 #	This program reads a config file, traverse through all .changes files
 #	in the specified directory and puts the files into the right place.
 #
-#    Copyright (C) 2000-2005 Ola Lundqvist <opal@debian.org>
+#    Copyright (C) 2000-2006 Ola Lundqvist <opal@debian.org>
 #    Copyright (C) 2004-2005 Russ Allbery <rra@stanford.edu>
 #    Copyright (C) 2005      Joel Baker <lucifer@lightbearer.com>
 #    Copyright (C) 2005      Daniel Leidert <daniel.leidert@wgdd.de>
 #    Copyright (C) 2005      Bob Proulx <bob@proulx.com>
+#    Copyright (C) 2006      Yaroslav Halchenko <debian@onerussian.com>
+#    Copyright (C) 2006      Jrmy Bobbio <jeremy.bobbio@etu.upmc.fr>
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -125,6 +127,9 @@ $distinputcriteria = "^kernel.*\\.deb\$";
 
 @sections = ('main', 'contrib', 'non-free');
 
+# Default major
+$majordefault = 'main';
+
 @mailtos = ();
 
 @ARGS1 = @ARGV;
@@ -258,8 +263,11 @@ else {
 #	by some perl module but this solution was good enough.
 #  2005-10-14 Daniel Leidert <daniel.leidert@wgdd.de>
 #	Removed signcmd.
+#  2006-02-25 Yaroslav Halchenko <debian@onerussian.com> and
+#             Ola Lundqvist <opal@debian.org>
+#       Default major section function.
 
-$version = "0.2.0";
+$version = "0.6.2";
 $versionstring = "Debian package archiver, version $version";
 
 $help =
@@ -283,6 +291,8 @@ options:
 			 This can be used to move away the old packages to
 			 some other place.
  --instcmd		DEPRICATED!
+ --majordefault section Default major section to use if undefined
+                        (default: main)
  -d | --dest dir       	Destination directory. The base directory where all
   --destdir dir		 the distribution packages reside. Here the
 			 \$distrib/\$major/\$arch/\$section directory structure
@@ -329,6 +339,7 @@ $etcconfigfile, $userconfigfile and $inputconfigfile".
     "(relative to input dir) that will be read before the arguments to this program
 will be parsed. Here you can change the following variables
 	\$destdir      	The destination directory (see --destdir above).
+	\$majordefault  Default major section (see --majordefault above).
 	\$inputdir	The input directory (no effect in $inputconfigfile).
         \$cachedir	The cache directory for apt-ftparchive, used if
 			--index is used.
@@ -364,6 +375,9 @@ will be parsed. Here you can change the following variables
 #	Added bzip2 support.
 #  2005-09-09 Ola Lundqvist <opal@debian.org>
 #       Added options for gpg signing support.
+#  2006-02-25 Yaroslav Halchenko <debian@onerussian.com> and
+#             Ola Lundqvist <opal@debian.org>
+#       Default major section function.
 
 while ($_ = shift @ARGS2) {
     if (/^-[a-zA-Z0-9]/) {
@@ -405,6 +419,10 @@ while ($_ = shift @ARGS2) {
 	    $destdir = shift @ARGS2;
 	    $destdir =~ s/\/$//;
 	}
+	elsif (/^--majordefault$/) {
+	    $majordefault = shift @ARGS2;
+	    $majordefault =~ s/\/$//;
+	}
 	elsif (/^--cachedir$/) {
 	    $cachedir = shift @ARGS2;
 	}
@@ -628,6 +646,7 @@ sub createRelease($$$$) {
 sub determineMailTo() {
     my $to = "";
     my $toi;
+    my %to_hash;
     foreach $toi (@mailtos) {
 	# Expand to email if there is no email address.
 	if ($toi !~ /\@/) {
@@ -643,16 +662,11 @@ sub determineMailTo() {
 	    }
 	}
 	if ($toi !~ /^\s*$/) {
-	    if ($to =~ /^\s*$/) {
-		$to = $toi;
-	    }
-	    else {
-		$to = "$to, $toi";
-	    }
+	    $to_hash{$toi} = "";
 	}
     }
     pdebug(5, "Mail will be sent to $to.");
-    return $to;
+    return join(", ", keys(%to_hash));
 }
 
 ###############################################################################
@@ -1754,6 +1768,9 @@ sub removeLockfile() {
 # Changelog:
 #  2001-06-10 Ola Lundqvist <opal@debian.org>
 #	Written.
+#  2006-02-25 Yaroslav Halchenko <debian@onerussian.com> and
+#             Ola Lundqvist <opal@debian.org>
+#       Default major section function.
 ###############################################################################
 
 sub parseSection($) {
@@ -1761,7 +1778,7 @@ sub parseSection($) {
     if ($section =~ /^\s*$/) {
 	# on the foo form.
 	$section = $major;
-	$major = "main";
+	$major = $majordefault;
     }
     return ($major, $section);
 }
@@ -1917,6 +1934,8 @@ sub parseDebOnlyFile($$) {
 #	Switched to using CMeta for ChangeLog meta information.
 #  2005-05-01 Ola Lundqvist <opal@debian.org>
 #	Renamed to parseChangesFile.
+#  2006-03-25 Jrmy Bobbio <jeremy.bobbio@etu.upmc.fr>
+#       One line fix for udeb support.
 ###############################################################################
 
 sub parseChangesFile($) {
@@ -1979,7 +1998,7 @@ sub parseChangesFile($) {
 	    pdebug(6, "Do nothing with $line\n");
 	}
 	# Files state.
-	elsif ($state =~ /Files/) {
+	elsif ($state =~ /Files/ && $line =~ /^ /) {
 	    my @f = split / /, $line;
 	    shift @f;
 	    my $file = pop @f;
@@ -2114,7 +2133,11 @@ Prints this information.
 =item B<--copycmd>
 
 The install command to use, default $copycmd. Both packages and .changes files are installed using this command.
- 
+
+=item B<--majordefault>
+
+Default major section to use if undefined (default: main)
+
 =item B<--movecmd>
 
 Command to move files (currently not used at all).
@@ -2231,6 +2254,10 @@ The cache directory for apt-ftparchive, used if --index is used.
 
 The install command (see --copycmd).
 
+=item B<$majordefault>
+
+Default major section (see --majordefault above).
+
 =item B<$movecmd>
 
 The move command (see --movecmd).
